import click
from src import blnconverter

@click.group(help="Easy tool for BLN shape files to ESRI shape or GeoJSON conversion.")
def cli():
    pass


cli.add_command(blnconverter.bln2shp)
cli.add_command(blnconverter.bln2geojson)

if __name__ == '__main__':
    cli()


import sys
import click
import logging
import pandas as pd
import geopandas as gpd
from pathlib import Path
from shapely.geometry import Polygon

# ignora um FutureWarning da dependência PyProj
import warnings
warnings.simplefilter(action='ignore', category=FutureWarning)

logger = logging.getLogger()
logging.basicConfig(format='%(asctime)s | %(levelname)s : %(message)s',
                    level=logging.INFO, stream=sys.stdout)


def converter(caminho: str, ext: str):
    caminho = Path(caminho)
    for item in caminho.glob("*.bln"):
        try:
            contorno = pd.read_csv(item, sep=",")
            longitude = contorno.iloc[:, 0].tolist()
            latitude = contorno.iloc[:, 1].tolist()
        except Exception:
            logging.error(f"'{item}' não parece estar íntegro.")
            continue
        else:
            geometria = Polygon(zip(longitude, latitude))
            poligono = gpd.GeoDataFrame(index=[0], crs={'init': 'epsg:4326'},
                                        geometry=[geometria])

            formatos = {
                "shp": {"ext": "shp",
                        "conversor": "ESRI Shapefile"},
                "geojson": {"ext": "geojson",
                            "conversor": "GeoJSON"}
            }

            ext_saida = formatos[ext]["ext"]
            conversor = formatos[ext]["conversor"]

            destino_arquivo_saida = Path(
                item.parent, f"{item.stem}.{ext_saida}")

            poligono.to_file(filename=destino_arquivo_saida,
                             driver=conversor)

            logging.info(f"{destino_arquivo_saida} gerado.")


@click.command("bln2shp")
@click.option('--path', '-p', help='Directory containing BLN files')
def bln2shp(path: Path):
    converter(path, ext="shp")
    
    
@click.command("bln2geojson")
@click.option('--path', '-p', help='Directory containing BLN files')
def bln2geojson(path: Path):
    converter(path, ext="geojson")



import setuptools

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setuptools.setup(
    name="bln-converter",
    version="1.0.0",
    author="Eric Miguel Ribeiro",
    author_email="ericmiguel@id.uff.br",
    description="Easy BLN file conversion to ESRI shape or GeoJSON",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/ericmiguel/bln-converter",
    install_requires=['certifi==2020.12.5',
                      'click==7.1.2',
                      'click-plugins==1.1.1',
                      'cligj==0.7.1',
                      'Fiona==1.8.18',
                      'geopandas==0.8.1',
                      'munch==2.5.0',
                      'numpy==1.19.5',
                      'pandas==1.2.0',
                      'pycodestyle==2.6.0',
                      'pyproj==3.0.0.post1',
                      'python-dateutil==2.8.1',
                      'pytz==2020.5',
                      'Shapely==1.7.1',
                      'six==1.15.0',
                      'toml==0.10.2'
    ],
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.7',
)